import os
import os.path
import warnings

import pytest

MARKER = "deprecated"


def get_fslocation_from_item(item):
    """
    :rtype: a tuple of (str|LocalPath, int) with filename and line number.
    """
    location, line = item.location[:2]
    location = os.path.realpath(location)
    return location, line


@pytest.mark.tryfirst
def pytest_load_initial_conftests(early_config, parser, args):
    """
    :param early_config:
    :param parser:
    :param args:
    :type args: tuple|list
    :return:
    """
    early_config.addinivalue_line(
        "markers", "%s: Mark the test as testing a deprecated feature." "" % MARKER
    )


def _process_marker(request, reason, *_args, **_kwargs):
    module_name = request.node.module.__name__
    test_name = request.node.name
    path, lineno = get_fslocation_from_item(request.node)
    warning = UserWarning(
        "%s:%s is testing a deprecated feature: %s" % (module_name, test_name, reason)
    )
    warnings.warn_explicit(
        warning,
        category=None,
        filename=str(path),
        lineno=lineno + 1 if lineno is not None else None,
    )


@pytest.fixture(autouse=True)
def _pytest_deprecated_test_marker(request):
    marker = request.node.get_closest_marker(MARKER)
    if marker:
        _process_marker(request, *marker.args, **marker.kwargs)



#!/usr/bin/env python

from os.path import isfile

from setuptools import setup


def _read_file(path):
    with open(path) as fp:
        return fp.read().strip()


PROJECT_VERSION = _read_file("VERSION.txt")

REQUIREMENTS = _read_file("requirements.txt").split("\n")
DEV_REQUIREMENTS = _read_file("requirements_dev.txt").split("\n")


if isfile("README.md"):
    long_description = _read_file("README.md")
else:
    long_description = ""

setup(
    name="pytest-deprecate",
    author="NyanKiyoshi",
    author_email="hello@vanille.bid",
    url="https://github.com/NyanKiyoshi/pytest-deprecate/",
    description="Mark tests as testing a deprecated feature with a warning note.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    version=PROJECT_VERSION,
    packages=["pytest_deprecate"],
    entry_points={"pytest11": ["pytest_deprecate = pytest_deprecate.plugin"]},
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Framework :: Pytest",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Topic :: Office/Business :: Financial",
        "License :: OSI Approved :: BSD License",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    install_requires=REQUIREMENTS,
    extras_require={"dev": DEV_REQUIREMENTS},
    zip_safe=False,
)
